@@ -20,7 +20,7 @@ from clade.extensions.opts import filter_opts
 
 
 class CDB(Extension):
-    requires = ["SrcGraph", "Storage"]
+    requires = ["SrcGraph"]
 
     __version__ = "1"
 
@@ -44,26 +44,27 @@ class CDB(Extension):
 
         for cmd in cmds:
             for i, cmd_in in enumerate(cmd["in"]):
+                if not os.path.exists(cmd_in):
+                    continue
+
                 if self.conf.get("CDB.filter_opts", False):
-                    opts = filter_opts(
-                        cmd["opts"], self.extensions["Storage"].get_storage_path
-                    )
+                    opts = filter_opts(cmd["opts"])
                 else:
                     opts = cmd["opts"]
 
                 arguments = [cmd["command"][0]] + opts + [cmd_in]
                 if cmd["out"]:
                     if "-c" in cmd["opts"]:
-                        arguments.extend(["-o", cmd["out"][i]])
+                        cmd_out = cmd["out"][i]
                     else:
-                        arguments.extend(["-o", cmd["out"][0]])
+                        cmd_out = cmd["out"][0]
+
+                    arguments.extend(["-o", cmd_out])
+                else:
+                    cmd_out = None
 
                 self.cdb.append(
-                    {
-                        "directory": cmd["cwd"],
-                        "arguments": arguments,
-                        "file": cmd_in,
-                    }
+                    self.__get_cdb_dict(cmd["cwd"], arguments, cmd_in, cmd_out)
                 )
 
         self.dump_data(self.cdb, self.cdb_file)
@@ -71,3 +72,15 @@ class CDB(Extension):
     def load_cdb(self):
         """Load compilation database."""
         return self.load_data(self.cdb_file)
+
+    def __get_cdb_dict(self, cwd, arguments, file, output=None):
+        cdb_dict = {
+            "directory": cwd,
+            "arguments": arguments,
+            "file": file,
+        }
+
+        if output:
+            cdb_dict["output"] = output
+
+        return cdb_dict
