@@ -25,13 +25,14 @@ import shutil
 import subprocess
 import sys
 import time
+import zipfile
 
 from clade.extensions.abstract import Extension
 from clade.extensions.opts import filter_opts
 
 
 class Info(Extension):
-    always_requires = ["SrcGraph", "Path", "Storage"]
+    always_requires = ["SrcGraph", "Storage"]
     requires = always_requires + ["CC", "CL"]
 
     __version__ = "2"
@@ -40,7 +41,8 @@ class Info(Extension):
         if not conf:
             conf = dict()
 
-        # Without this option it will be difficult to link data coming from Info and by CC extensions
+        # Without this option it will be difficult to link data
+        # coming from Info and by CC extensions
         conf["CC.with_system_header_files"] = True
 
         if "SrcGraph.requires" in conf:
@@ -53,27 +55,27 @@ class Info(Extension):
         )
 
         # Info about function definitions
-        self.execution = os.path.join(self.work_dir, "execution.txt")
+        self.execution = os.path.join(self.work_dir, "execution.zip")
         # Info about function calls
-        self.call = os.path.join(self.work_dir, "call.txt")
+        self.call = os.path.join(self.work_dir, "call.zip")
         # Info about function declarations
-        self.decl = os.path.join(self.work_dir, "declare_func.txt")
+        self.decl = os.path.join(self.work_dir, "declare_func.zip")
         # Info about function calls via a function pointer
-        self.callp = os.path.join(self.work_dir, "callp.txt")
+        self.callp = os.path.join(self.work_dir, "callp.zip")
         # Info about using function names in pointers (in function context only)
-        self.use_func = os.path.join(self.work_dir, "use_func.txt")
+        self.use_func = os.path.join(self.work_dir, "use_func.zip")
         # Info about using global variables in function context
-        self.use_var = os.path.join(self.work_dir, "use_var.txt")
+        self.use_var = os.path.join(self.work_dir, "use_var.zip")
         # Info about init values of global variables
-        self.init_global = os.path.join(self.work_dir, "init_global.txt")
+        self.init_global = os.path.join(self.work_dir, "init_global.zip")
         # Info about macro functions
-        self.define = os.path.join(self.work_dir, "define.txt")
+        self.define = os.path.join(self.work_dir, "define.zip")
         # Info about macros
-        self.expand = os.path.join(self.work_dir, "expand.txt")
+        self.expand = os.path.join(self.work_dir, "expand.zip")
         # Info about exported functions (Linux kernel only)
-        self.exported = os.path.join(self.work_dir, "exported.txt")
+        self.exported = os.path.join(self.work_dir, "exported.zip")
         # Info about typedefs
-        self.typedefs = os.path.join(self.work_dir, "typedefs.txt")
+        self.typedefs = os.path.join(self.work_dir, "typedefs.zip")
 
         self.files = [
             self.execution,
@@ -100,15 +102,7 @@ class Info(Extension):
 
     @Extension.prepare
     def parse(self, cmds_file):
-        if not shutil.which(self.conf.get("Info.cif", "cif")):
-            raise RuntimeError("Can't find CIF in PATH")
-
-        # Check that CIF was not added in PATH via relative path
-        current_dir = os.getcwd()
-        os.chdir(self.temp_dir)
-        if not shutil.which(self.conf.get("Info.cif", "cif")):
-            raise RuntimeError("Path to CIF must be absolute")
-        os.chdir(current_dir)
+        self.__check_cif()
 
         cmds = list(self.extensions["SrcGraph"].load_all_cmds())
 
@@ -135,10 +129,21 @@ class Info(Extension):
         if not os.path.exists(self.err_log):
             self.log("CIF finished without errors")
         else:
-            self.log("CIF finished with errors. Log: {}".format(self.err_log))
+            self.log("CIF finished with errors")
 
         self.__normalize_cif_output(cif_output)
 
+    def __check_cif(self):
+        if not shutil.which(self.conf.get("Info.cif", "cif")):
+            raise RuntimeError("Can't find CIF in PATH")
+
+        # Check that CIF was not added in PATH via relative path
+        current_dir = os.getcwd()
+        os.chdir(self.temp_dir)
+        if not shutil.which(self.conf.get("Info.cif", "cif")):
+            raise RuntimeError("Path to CIF must be absolute")
+        os.chdir(current_dir)
+
     def _run_cif(self, cmd):
         if self.__is_cmd_bad_for_cif(cmd):
             return
@@ -152,29 +157,25 @@ class Info(Extension):
         )
 
         for cmd_in in cmd["in"]:
-            norm_cmd_in = self.extensions["Path"].get_rel_path(
-                cmd_in, cmd["cwd"]
-            )
-
-            cmd_in = self.extensions["Storage"].get_storage_path(norm_cmd_in)
+            storage_cmd_in = self.extensions["Storage"].get_storage_path(cmd_in)
 
             if use_pre:
                 cif_in = self.extensions[cmd["type"]].get_pre_file_by_path(
-                    norm_cmd_in, cmd["cwd"]
+                    cmd_in, cmd["cwd"]
                 )
             else:
-                cif_in = cmd_in
+                cif_in = storage_cmd_in
 
             if not os.path.exists(cif_in):
                 continue
 
             cif_out = os.path.join(
-                tmp_dir, os.path.basename(cmd_in.lstrip(os.sep)) + ".o"
+                tmp_dir, os.path.basename(storage_cmd_in.lstrip(os.sep)) + ".o"
             )
 
             cif_env = {
                 "CIF_INFO_DIR": self.cif_output_dir,
-                "C_FILE": norm_cmd_in
+                "C_FILE": cmd_in
             }
 
             cif_args = [
@@ -207,8 +208,7 @@ class Info(Extension):
                 cif_args.append("--")
                 cif_args.extend(opts)
 
-            cwd = self.extensions["Path"].get_abs_path(cmd["cwd"])
-            cwd = self.extensions["Storage"].get_storage_path(cwd)
+            cwd = self.extensions["Storage"].get_storage_path(cmd["cwd"])
             os.makedirs(cwd, exist_ok=True)
 
             # env is for subprocess
@@ -216,7 +216,6 @@ class Info(Extension):
             env.update(cif_env)
 
             try:
-                self.debug(cif_args)
                 output = subprocess.check_output(
                     cif_args,
                     stderr=subprocess.STDOUT,
@@ -235,13 +234,16 @@ class Info(Extension):
 
     def __is_cmd_bad_for_cif(self, cmd):
         if not cmd["in"]:
+            self.debug("Command {} is bad for CIF".format(cmd))
             return True
 
         for cif_in in cmd["in"]:
             if cif_in == "-" or cif_in == "/dev/null":
+                self.debug("Command {} is bad for CIF".format(cmd))
                 return True
             elif re.search(r"\.[sS]$", cif_in):
                 # Assembler files are not supported
+                self.debug("Command {} is bad for CIF".format(cmd))
                 return True
 
         return False
@@ -288,7 +290,7 @@ class Info(Extension):
             futures = []
             finished_files = 0
 
-            init_global = os.path.basename(self.init_global)
+            init_global = os.path.basename(self.init_global).replace(".zip", ".txt")
             files = [f for f in cif_output if not f.endswith(init_global)]
             total_files = len(files)
 
@@ -341,19 +343,27 @@ class Info(Extension):
 
         # Join all cif output file into several big .txt files
         for file in self.files:
-            output_type = os.path.basename(file)
+            output_type = os.path.basename(file).replace(".zip", ".txt")
 
-            for output_file in [f for f in cif_output if f.endswith(output_type)]:
-                with open(file, "a") as file_fh:
-                    with open(output_file, "r") as output_fh:
-                        # This files should be fairly small
-                        file_fh.write(output_fh.read())
+            with zipfile.ZipFile(file, "w") as zip_fh:
+                for output_file in [f for f in cif_output if f.endswith(output_type)]:
+                    # Remove unnecessary prefixes from path inside archive
+                    arcname = output_file.replace(storage, "")
+                    arcname = arcname.replace(self.cif_output_dir, "")
+
+                    zip_fh.write(output_file, arcname=arcname)
 
         # Remove cif output directory
         if os.path.exists(self.cif_output_dir):
             shutil.rmtree(self.cif_output_dir)
 
-        self.log("Normalizing finished")
+    def iter_init_global(self):
+        """Yield data from init_global.zip"""
+        with zipfile.ZipFile(self.init_global, "r") as zip_fh:
+            for file in zip_fh.namelist():
+                with zip_fh.open(file, "r") as f:
+                    for line in f:
+                        yield line.decode("utf-8")
 
     def iter_definitions(self):
         """Yield src_file, func, def_line, func_type, signature"""
@@ -385,10 +395,11 @@ class Info(Extension):
         regex = re.compile(r'\"(.*?)\" (\S*) (\S*) (\S*) (\S*) (.*)')
         args_regex = re.compile(r"actual_arg_func_name(\d+)=\s*(\w+)\s*")
 
-        for content in self.__iter_file_regex(self.call, regex):
-            content = list(content)
+        for orig_content in self.__iter_file_regex(self.call, regex):
+            content = list(orig_content)
 
-            # Last element should be args
+            # Replace last element of content list (string with arguments)
+            # with list of these arguments
             content[-1] = args_regex.findall(content[-1])
 
             yield content
@@ -423,12 +434,13 @@ class Info(Extension):
         regex = re.compile(r'\"(.*?)\" \"(.*?)\" (\S*) (\S*) (\S*)(.*)')
         arg_regex = re.compile(r' actual_arg\d+=(.*)')
 
-        for content in self.__iter_file_regex(self.expand, regex):
-            content = list(content)
+        for orig_content in self.__iter_file_regex(self.expand, regex):
+            content = list(orig_content)
 
             args = list()
 
-            # Last element should be args
+            # Replace last element of content list (string with arguments)
+            # with list of these arguments
             if content[-1]:
                 for arg in content[-1].split(','):
                     m_arg = arg_regex.match(arg)
@@ -447,23 +459,40 @@ class Info(Extension):
         for content in self.__iter_file_regex(self.typedefs, regex):
             yield content
 
-    def __iter_file_regex(self, file, regex):
-        for line in self.__iter_file(file):
-            m = regex.match(line)
+    def __iter_file_regex(self, archive, regex):
+        with zipfile.ZipFile(archive, "r") as zip_fh:
+            for file in zip_fh.namelist():
+                for line in self.__iter_file(file, zip_fh):
+                    m = regex.match(line)
 
-            if not m:
-                self.error("CIF output has unexpected format: {!r}".format(line))
-                raise SyntaxError
+                    if not m:
+                        self.error("CIF output has unexpected format: {!r}".format(line))
+                        raise SyntaxError
 
-            yield m.groups()
+                    yield m.groups()
 
-    def __iter_file(self, file):
-        if not os.path.isfile(file):
-            return []
+    def __iter_file(self, file, zip_fh):
+        # Path to the source file is encoded in the path to the CIF output file
+        path = os.path.dirname(file)
 
-        with open(file, "r") as f:
+        if "\\/" in path:
+            raise RuntimeError("Normalized path looks weird: {!r}".format(path))
+
+        # Path to the defenition of macro expansion
+        def_path = None
+
+        expand_file = True if file.endswith("expand.txt") else False
+
+        if expand_file:
+            path, def_path = path.split("/CLADE-EXPAND")
+
+        with zip_fh.open(file, "r") as f:
             for line in f:
-                yield line
+                # paths inside archives do not start with /, so we fix it
+                if expand_file:
+                    yield '"/{}" "{}" {}'.format(path, def_path, line.decode("utf-8"))
+                else:
+                    yield '"/{}" {}'.format(path, line.decode("utf-8"))
 
 
 # Moving this function outside output_file class increases performance
@@ -471,20 +500,6 @@ def normalize_file(file, storage, cif_output_dir, expand):
     if not os.path.isfile(file):
         return
 
-    # Path to the source file is encoded in the path to the CIF output file
-    path = os.path.dirname(file)
-
-    path = path.replace(storage, "")
-    path = path.replace(cif_output_dir, "")
-
-    if "\\/" in path:
-        raise "Normalized path looks weird: {!r}".format(path)
-
-    expand_file = True if file.endswith(expand) else False
-
-    if expand_file:
-        path, def_path = path.split("/CLADE-EXPAND")
-
     seen = set()
     new_file = file + ".tmp"
 
@@ -503,10 +518,7 @@ def normalize_file(file, storage, cif_output_dir, expand):
 
                     seen.add(h)
 
-                    if expand_file:
-                        new_fh.write('"{}" "{}" {}'.format(path, def_path, line))
-                    else:
-                        new_fh.write('"{}" {}'.format(path, line))
+                    new_fh.write(line)
     else:
         lines = []
         with codecs.open(file, "r", encoding="utf8", errors="ignore") as fh:
@@ -520,10 +532,7 @@ def normalize_file(file, storage, cif_output_dir, expand):
 
                 seen.add(h)
 
-                if expand_file:
-                    new_lines.append('"{}" "{}" {}'.format(path, def_path, line))
-                else:
-                    new_lines.append('"{}" {}'.format(path, line))
+                new_lines.append(line)
 
             with open(new_file, "w") as new_fh:
                 new_fh.writelines(new_lines)
