@@ -18,6 +18,9 @@
 #include <spawn.h>
 #include <stdbool.h>
 #include <unistd.h>
+#include <stdarg.h>
+#include <fcntl.h>
+#include <stdlib.h>
 
 #define __USE_GNU
 #include <dlfcn.h>
@@ -38,11 +41,11 @@ pid_t vfork() {
 int execve(const char *path, char *const argv[], char *const envp[]) {
     int (*execve_real)(const char *, char *const *, char *const *) = dlsym(RTLD_NEXT, "execve");
 
-    if (! intercepted) {
+    if (!intercepted && getenv(CLADE_INTERCEPT_EXEC_ENV)) {
         // Extract some data from envp
         update_environ((char **)envp);
         // Store information about intercepted call
-        intercept_call(path, (char const *const *)argv);
+        intercept_exec_call(path, (char const *const *)argv);
         intercepted = true;
 
         // Put updated data back to envp
@@ -57,8 +60,8 @@ int execve(const char *path, char *const argv[], char *const envp[]) {
 int execvp(const char *filename, char *const argv[]) {
     int (*execvp_real)(const char *, char *const *) = dlsym(RTLD_NEXT, "execvp");
 
-    if (! intercepted) {
-        intercept_call(filename, (char const *const *)argv);
+    if (!intercepted && getenv(CLADE_INTERCEPT_EXEC_ENV)) {
+        intercept_exec_call(filename, (char const *const *)argv);
         // DO NOT change value of intercepted to TRUE here
     }
 
@@ -70,7 +73,9 @@ int execv(const char *filename, char *const argv[]) {
 
     // DO NOT check if (! intercepted) here: it will result in command loss
     // Also DO NOT change value of intercepted to TRUE for the same reason
-    intercept_call(filename, (char const *const *)argv);
+    if (getenv(CLADE_INTERCEPT_EXEC_ENV)) {
+        intercept_exec_call(filename, (char const *const *)argv);
+    }
     // BUT we need to change it for macOS to avoid duplicating commands
     #ifdef __APPLE__
     intercepted = true;
@@ -86,9 +91,9 @@ int posix_spawn(pid_t *restrict pid, const char *restrict path, const posix_spaw
                 const posix_spawnattr_t *restrict, char *const *restrict, char *const *restrict) = dlsym(RTLD_NEXT, "posix_spawn");
 
     // DO NOT check if (! intercepted) here: it will result in command loss
-    if ((access(path, F_OK ) != -1) && argv) {
+    if ((access(path, F_OK ) != -1) && getenv(CLADE_INTERCEPT_EXEC_ENV) && argv) {
         update_environ((char **)envp);
-        intercept_call(path, (char const *const *)argv);
+        intercept_exec_call(path, (char const *const *)argv);
         intercepted = true;
 
         char **new_envp = update_envp((char **)envp);
@@ -97,3 +102,42 @@ int posix_spawn(pid_t *restrict pid, const char *restrict path, const posix_spaw
 
     return posix_spawn_real(pid, path, file_actions, attrp, argv, envp);
 }
+
+int open(const char *pathname, int flags, ...) {
+    int (*open_real)(const char *, int, ...) = dlsym(RTLD_NEXT, "open");
+
+    if (getenv(CLADE_INTERCEPT_OPEN_ENV)) {
+        intercept_open_call(pathname, flags);
+    }
+
+    // If O_CREAT is used to create a file, the file access mode must be given.
+    if (flags & O_CREAT) {
+        va_list args;
+        va_start(args, flags);
+        mode_t mode = va_arg(args, int);
+        va_end(args);
+        return open_real(pathname, flags, mode);
+    } else {
+        return open_real(pathname, flags);
+    }
+}
+
+
+int open64(const char *pathname, int flags, ...) {
+    int (*open_real)(const char *, int, ...) = dlsym(RTLD_NEXT, "open64");
+
+    if (getenv(CLADE_INTERCEPT_OPEN_ENV)) {
+        intercept_open_call(pathname, flags);
+    }
+
+    // If O_CREAT is used to create a file, the file access mode must be given.
+    if (flags & O_CREAT) {
+        va_list args;
+        va_start(args, flags);
+        mode_t mode = va_arg(args, int);
+        va_end(args);
+        return open_real(pathname, flags, mode);
+    } else {
+        return open_real(pathname, flags);
+    }
+}
